@@ -25,12 +25,13 @@ class DateTimeFormatDataCheck(DataCheck):
         Returns:
             dict (DataCheckError): List with DataCheckErrors if unequal intervals are found in the datetime column.
 
-        Example:
+        Examples:
             >>> import pandas as pd
+            ...
             >>> X = pd.DataFrame(pd.date_range("2021-01-01", periods=9).append(pd.date_range("2021-01-31", periods=1)), columns=["dates"])
             >>> y = pd.Series([0, 1, 0, 1, 1, 0, 0, 0, 1, 0])
-            >>> datetime_format_check = DateTimeFormatDataCheck(datetime_column="dates")
-            >>> assert datetime_format_check.validate(X, y) == {
+            >>> datetime_format_dc = DateTimeFormatDataCheck(datetime_column="dates")
+            >>> assert datetime_format_dc.validate(X, y) == {
             ...     "errors": [{"message": "No frequency could be detected in dates, possibly due to uneven intervals.",
             ...                 "data_check_name": "DateTimeFormatDataCheck",
             ...                 "level": "error",
@@ -39,6 +40,41 @@ class DateTimeFormatDataCheck(DataCheck):
             ...                 }],
             ...     "warnings": [],
             ...     "actions": []}
+            ...
+            ...
+            >>> X = pd.DataFrame([1, 2, 3, 4], columns=["Weeks"])
+            >>> y = pd.Series([0] * 4)
+            >>> datetime_format_dc = DateTimeFormatDataCheck(datetime_column="Weeks")
+            >>> assert datetime_format_dc.validate(X, y) == {
+            ...     'warnings': [],
+            ...     'errors': [{'message': 'Datetime information could not be found in the data, or was not in a supported datetime format.',
+            ...                 'data_check_name': 'DateTimeFormatDataCheck',
+            ...                 'level': 'error',
+            ...                 'details': {'columns': None, 'rows': None},
+            ...                 'code': 'DATETIME_INFORMATION_NOT_FOUND'}],
+            ...     'actions': []}
+            ...
+            ...
+            >>> X = pd.DataFrame(pd.to_datetime([1, 2, 3, 4]), columns=["Weeks"])
+            >>> datetime_format_dc = DateTimeFormatDataCheck(datetime_column="Weeks")
+            >>> assert datetime_format_dc.validate(X, y) == {'warnings': [], 'errors': [], 'actions': []}
+            ...
+            ...
+            >>> X = pd.DataFrame(pd.date_range("2021-01-01", freq='W', periods=10), columns=["Weeks"])
+            >>> datetime_format_dc = DateTimeFormatDataCheck(datetime_column="Weeks")
+            >>> assert datetime_format_dc.validate(X, y) == {'warnings': [], 'errors': [], 'actions': []}
+            ...
+            ...
+            >>> X = X.iloc[::-1]
+            >>> datetime_format_dc = DateTimeFormatDataCheck(datetime_column="Weeks")
+            >>> assert datetime_format_dc.validate(X, y) == {
+            ...     'warnings': [],
+            ...     'errors': [{'message': 'Datetime values must be sorted in ascending order.',
+            ...                 'data_check_name': 'DateTimeFormatDataCheck',
+            ...                 'level': 'error',
+            ...                 'details': {'columns': None, 'rows': None},
+            ...                 'code': 'DATETIME_IS_NOT_MONOTONIC'}],
+            ...     'actions': []}
         """
         results = {"warnings": [], "errors": [], "actions": []}
 
