@@ -26,8 +26,8 @@ from .components import (
     ExtraTreesRegressor,
     DecisionTreeClassifier,
     DecisionTreeRegressor,
-    SklearnStackedEnsembleClassifier,
-    SklearnStackedEnsembleRegressor,
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
     DelayedFeatureTransformer,
     DFSTransformer,
     KNeighborsClassifier,
@@ -35,6 +35,9 @@ from .components import (
     SVMRegressor,
     ARIMARegressor,
     ProphetRegressor,
+    VowpalWabbitBinaryClassifier,
+    VowpalWabbitMulticlassClassifier,
+    VowpalWabbitRegressor,
 )
 
 from .component_graph import ComponentGraph
