@@ -26,6 +26,9 @@ from .estimators import (
     SVMClassifier,
     SVMRegressor,
     ARIMARegressor,
+    VowpalWabbitBinaryClassifier,
+    VowpalWabbitMulticlassClassifier,
+    VowpalWabbitRegressor,
 )
 from .transformers import (
     Transformer,
@@ -57,5 +60,9 @@ from .transformers import (
     EmailFeaturizer,
     URLFeaturizer,
     DropRowsTransformer,
+    LabelEncoder,
+)
+from .ensemble import (
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor,
 )
-from .ensemble import SklearnStackedEnsembleClassifier, SklearnStackedEnsembleRegressor
