@@ -7,7 +7,8 @@ class TimeSeriesRegressionPipeline(TimeSeriesPipelineBase):
     """Pipeline base class for time series regression problems.
 
     Args:
-        component_graph (list or dict): List of components in order. Accepts strings or ComponentBase subclasses in the list.
+        component_graph (ComponentGraph, list, dict): ComponentGraph instance, list of components in order, or dictionary of components.
+            Accepts strings or ComponentBase subclasses in the list.
             Note that when duplicate components are specified in a list, the duplicate component names will be modified with the
             component's index in the list. For example, the component graph
             [Imputer, One Hot Encoder, Imputer, Logistic Regression Classifier] will have names
@@ -17,6 +18,20 @@ class TimeSeriesRegressionPipeline(TimeSeriesPipelineBase):
              parameters such as date_index, gap, and max_delay must be specified with the "pipeline" key. For example:
              Pipeline(parameters={"pipeline": {"date_index": "Date", "max_delay": 4, "gap": 2}}).
         random_seed (int): Seed for the random number generator. Defaults to 0.
+
+    Example:
+        >>> pipeline = TimeSeriesRegressionPipeline(component_graph=["Simple Imputer", "Linear Regressor"],
+        ...                                                       parameters={"Linear Regressor": {"normalize": True},
+        ...                                                                   "pipeline": {"gap": 1, "max_delay": 1, "forecast_horizon": 1, "date_index": None}},
+        ...                                                       custom_name="My TimeSeriesRegression Pipeline")
+        ...
+        >>> assert pipeline.custom_name == "My TimeSeriesRegression Pipeline"
+        >>> assert pipeline.component_graph.component_dict.keys() == {'Simple Imputer', 'Linear Regressor'}
+        ...
+        >>> assert pipeline.parameters == {
+        ...     'Simple Imputer': {'impute_strategy': 'most_frequent', 'fill_value': None},
+        ...     'Linear Regressor': {'fit_intercept': True, 'normalize': True, 'n_jobs': -1},
+        ...     'pipeline': {'gap': 1, 'max_delay': 1, 'forecast_horizon': 1, 'date_index': None}}
     """
 
     problem_type = ProblemTypes.TIME_SERIES_REGRESSION
