@@ -1,3 +1,4 @@
+"""Rolling Origin Cross Validation for time series problems."""
 from sklearn.model_selection import TimeSeriesSplit as SkTimeSeriesSplit
 from sklearn.model_selection._split import BaseCrossValidator
 
@@ -10,7 +11,7 @@ class TimeSeriesSplit(BaseCrossValidator):
     desired amount. If the data that will be split already has all the features and appropriate target values, and
     then set max_delay and gap to 0.
 
-    Arguments:
+    Args:
         max_delay (int): Max delay value for feature engineering. Time series pipelines create delayed features
             from existing features. This process will introduce NaNs into the first max_delay number of rows. The
             splitter uses the last max_delay number of rows from the previous split as the first max_delay number
@@ -18,6 +19,35 @@ class TimeSeriesSplit(BaseCrossValidator):
         gap (int): Gap used in time series problem. Time series pipelines shift the target variable by gap rows. Defaults to 0.
         date_index (str): Name of the column containing the datetime information used to order the data. Defaults to None.
         n_splits (int): number of data splits to make. Defaults to 3.
+
+    Example:
+        >>> import numpy as np
+        >>> import pandas as pd
+        ...
+        >>> X = pd.DataFrame([i for i in range(10)], columns=["First"])
+        >>> y = pd.Series([i for i in range(10)])
+        ...
+        >>> ts_split = TimeSeriesSplit(n_splits=4)
+        >>> generator_ = ts_split.split(X, y)
+        ...
+        >>> first_split = next(generator_)
+        >>> assert (first_split[0] == np.array([0, 1])).all()
+        >>> assert (first_split[1] == np.array([2, 3])).all()
+        ...
+        ...
+        >>> second_split = next(generator_)
+        >>> assert (second_split[0] == np.array([0, 1, 2, 3])).all()
+        >>> assert (second_split[1] == np.array([4, 5])).all()
+        ...
+        ...
+        >>> third_split = next(generator_)
+        >>> assert (third_split[0] == np.array([0, 1, 2, 3, 4, 5])).all()
+        >>> assert (third_split[1] == np.array([6, 7])).all()
+        ...
+        ...
+        >>> fourth_split = next(generator_)
+        >>> assert (fourth_split[0] == np.array([0, 1, 2, 3, 4, 5, 6, 7])).all()
+        >>> assert (fourth_split[1] == np.array([8, 9])).all()
     """
 
     def __init__(self, max_delay=0, gap=0, date_index=None, n_splits=3):
@@ -28,7 +58,16 @@ class TimeSeriesSplit(BaseCrossValidator):
         self._splitter = SkTimeSeriesSplit(n_splits=n_splits)
 
     def get_n_splits(self, X=None, y=None, groups=None):
-        """Get the number of data splits."""
+        """Get the number of data splits.
+
+        Args:
+            X (pd.DataFrame, None): Features to split.
+            y (pd.DataFrame, None): Target variable to split. Defaults to None.
+            groups: Ignored but kept for compatibility with sklearn API. Defaults to None.
+
+        Returns:
+            Number of splits.
+        """
         return self._splitter.n_splits
 
     @staticmethod
@@ -42,13 +81,16 @@ class TimeSeriesSplit(BaseCrossValidator):
         This method can handle passing in empty or None X and y data but note that X and y cannot be None or empty
         at the same time.
 
-        Arguments:
+        Args:
             X (pd.DataFrame, None): Features to split.
-            y (pd.DataFrame, None): Target variable to split.
-            groups: Ignored but kept for compatibility with sklearn api.
+            y (pd.DataFrame, None): Target variable to split. Defaults to None.
+            groups: Ignored but kept for compatibility with sklearn API. Defaults to None.
 
-        Returns:
+        Yields:
             Iterator of (train, test) indices tuples.
+
+        Raises:
+            ValueError: If one of the proposed splits would be empty.
         """
         # Sklearn splitters always assume a valid X is passed but we need to support the
         # TimeSeriesPipeline convention of being able to pass in empty X dataframes
