@@ -1,3 +1,4 @@
+"""Helpful preprocessing utilities."""
 import pandas as pd
 from sklearn.model_selection import ShuffleSplit, StratifiedShuffleSplit
 
@@ -13,18 +14,18 @@ from evalml.utils import infer_feature_types
 def load_data(path, index, target, n_rows=None, drop=None, verbose=True, **kwargs):
     """Load features and target from file.
 
-    Arguments:
-        path (str): Path to file or a http/ftp/s3 URL
-        index (str): Column for index
-        target (str): Column for target
-        n_rows (int): Number of rows to return
-        drop (list): List of columns to drop
-        verbose (bool): If True, prints information about features and target
+    Args:
+        path (str): Path to file or a http/ftp/s3 URL.
+        index (str): Column for index.
+        target (str): Column for target.
+        n_rows (int): Number of rows to return. Defaults to None.
+        drop (list): List of columns to drop. Defaults to None.
+        verbose (bool): If True, prints information about features and target. Defaults to True.
+        **kwargs: Other keyword arguments that should be passed to panda's `read_csv` method.
 
     Returns:
-       pd.DataFrame, pd.Series: Features matrix and target
+        pd.DataFrame, pd.Series: Features matrix and target.
     """
-
     feature_matrix = pd.read_csv(path, index_col=index, nrows=n_rows, **kwargs)
 
     targets = [target] + (drop or [])
@@ -48,9 +49,9 @@ def load_data(path, index, target, n_rows=None, drop=None, verbose=True, **kwarg
 def split_data(
     X, y, problem_type, problem_configuration=None, test_size=0.2, random_seed=0
 ):
-    """Splits data into train and test sets.
+    """Split data into train and test sets.
 
-    Arguments:
+    Args:
         X (pd.DataFrame or np.ndarray): data of shape [n_samples, n_features]
         y (pd.Series, or np.ndarray): target data of length [n_samples]
         problem_type (str or ProblemTypes): type of supervised learning problem. see evalml.problem_types.problemtype.all_problem_types for a full list.
@@ -60,7 +61,33 @@ def split_data(
         random_seed (int): Seed for the random number generator. Defaults to 0.
 
     Returns:
-        pd.DataFrame, pd.DataFrame, pd.Series, pd.Series: Feature and target data each split into train and test sets
+        pd.DataFrame, pd.DataFrame, pd.Series, pd.Series: Feature and target data each split into train and test sets.
+
+    Examples:
+        >>> X = pd.DataFrame([1, 2, 3, 4, 5, 6], columns=["First"])
+        >>> y = pd.Series([8, 9, 10, 11, 12, 13])
+        ...
+        >>> X_train, X_validation, y_train, y_validation = split_data(X, y, "regression", random_seed=42)
+        >>> X_train
+           First
+        5      6
+        2      3
+        4      5
+        3      4
+        >>> X_validation
+           First
+        0      1
+        1      2
+        >>> y_train
+        5    13
+        2    10
+        4    12
+        3    11
+        dtype: int64
+        >>> y_validation
+        0    8
+        1    9
+        dtype: int64
     """
     X = infer_feature_types(X)
     y = infer_feature_types(y)
@@ -92,11 +119,23 @@ def split_data(
 def number_of_features(dtypes):
     """Get the number of features of each specific dtype in a DataFrame.
 
-    Arguments:
-        dtypes (pd.Series): DataFrame.dtypes to get the number of features for
+    Args:
+        dtypes (pd.Series): DataFrame.dtypes to get the number of features for.
 
     Returns:
-        pd.Series: dtypes and the number of features for each input type
+        pd.Series: dtypes and the number of features for each input type.
+
+    Example:
+        >>> X = pd.DataFrame()
+        >>> X["integers"] = [i for i in range(10)]
+        >>> X["floats"] = [float(i) for i in range(10)]
+        >>> X["strings"] = [str(i) for i in range(10)]
+        >>> X["booleans"] = [bool(i%2) for i in range(10)]
+        >>> number_of_features(X.dtypes)
+                     Number of Features
+        Boolean                       1
+        Categorical                   1
+        Numeric                       2
     """
     dtype_to_vtype = {
         "bool": "Boolean",
@@ -114,11 +153,27 @@ def number_of_features(dtypes):
 def target_distribution(targets):
     """Get the target distributions.
 
-    Arguments:
-        targets (pd.Series): Target data
+    Args:
+        targets (pd.Series): Target data.
 
     Returns:
         pd.Series: Target data and their frequency distribution as percentages.
+
+    Examples:
+        >>> y = pd.Series([1, 2, 4, 1, 3, 3, 1, 2])
+        >>> target_distribution(y)
+        Targets
+        1    37.50%
+        2    25.00%
+        3    25.00%
+        4    12.50%
+        dtype: object
+        >>> y = pd.Series([True, False, False, False, True])
+        >>> target_distribution(y)
+        Targets
+        False    60.00%
+        True     40.00%
+        dtype: object
     """
     distribution = targets.value_counts() / len(targets)
     return distribution.mul(100).apply("{:.2f}%".format).rename_axis("Targets")
