@@ -1155,6 +1155,7 @@ def test_automl_supports_time_series_classification(
         "forecast_horizon": 1,
         "delay_target": False,
         "delay_features": True,
+        "conf_level": 0.05,
     }
 
     automl = AutoMLSearch(
@@ -1629,3 +1630,31 @@ def test_time_series_pipeline_parameter_warnings(
     assert len(w) == (2 if len(set_values) else 1)
     if len(w) == 2:
         assert w[1].message.components == set_values
+
+
+@pytest.mark.parametrize("allow_long_running_models", [True, False])
+@pytest.mark.parametrize("unique", [10, 200])
+def test_automl_passes_allow_long_running_models_iterative(
+    unique, allow_long_running_models, caplog, has_minimal_dependencies
+):
+    X = pd.DataFrame()
+    y = pd.Series([i for i in range(unique)] * 5)
+    automl = AutoMLSearch(
+        X_train=X,
+        y_train=y,
+        problem_type="multiclass",
+        allow_long_running_models=allow_long_running_models,
+        _automl_algorithm="iterative",
+        verbose=True,
+    )
+    assert (
+        automl._automl_algorithm.allow_long_running_models == allow_long_running_models
+    )
+    if allow_long_running_models or unique == 10:
+        assert "Dropping estimators" not in caplog.text
+        return
+    estimators = ["Elastic Net Classifier"]
+    if not has_minimal_dependencies:
+        estimators.extend(["CatBoost Classifier", "XGBoost Classifier"])
+
+    assert "Dropping estimators {}".format(", ".join(sorted(estimators))) in caplog.text
