@@ -2,8 +2,11 @@ import string
 
 import numpy as np
 import pandas as pd
+import pytest
 
 from evalml.data_checks import (
+    DataCheckAction,
+    DataCheckActionCode,
     DataCheckMessageCode,
     DataCheckWarning,
     OutliersDataCheck,
@@ -32,12 +35,17 @@ def test_outliers_data_check_warnings():
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
                 details={
                     "columns": [3, 25, 55, 72],
-                    "rows": {3: [0], 25: [3], 55: [5], 72: [10]},
+                    "rows": [0, 3, 5, 10],
+                    "column_indices": {3: [0], 25: [3], 55: [5], 72: [10]},
                 },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [0, 3, 5, 10]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 3, 5, 10]}
+            ).to_dict()
+        ],
     }
 
 
@@ -61,12 +69,17 @@ def test_outliers_data_check_warnings_with_duplicate_outlier_indices():
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
                 details={
                     "columns": [3, 25, 55, 72],
-                    "rows": {3: [0], 25: [3], 55: [0], 72: [0]},
+                    "rows": [0, 3],
+                    "column_indices": {3: [0], 25: [3], 55: [0], 72: [0]},
                 },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [0, 3]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 3]}
+            ).to_dict()
+        ],
     }
 
 
@@ -99,12 +112,17 @@ def test_outliers_data_check_input_formats():
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
                 details={
                     "columns": [3, 25, 55, 72],
-                    "rows": {3: [0], 25: [3], 55: [5], 72: [10]},
+                    "rows": [0, 3, 5, 10],
+                    "column_indices": {3: [0], 25: [3], 55: [5], 72: [10]},
                 },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [0, 3, 5, 10]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 3, 5, 10]}
+            ).to_dict()
+        ],
     }
 
     # test Woodwork
@@ -118,12 +136,17 @@ def test_outliers_data_check_input_formats():
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
                 details={
                     "columns": [3, 25, 55, 72],
-                    "rows": {3: [0], 25: [3], 55: [5], 72: [10]},
+                    "rows": [0, 3, 5, 10],
+                    "column_indices": {3: [0], 25: [3], 55: [5], 72: [10]},
                 },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [0, 3, 5, 10]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 3, 5, 10]}
+            ).to_dict()
+        ],
     }
 
 
@@ -144,11 +167,19 @@ def test_outliers_data_check_string_cols():
                 message="Column(s) 'd' are likely to have outlier data.",
                 data_check_name=outliers_data_check_name,
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
-                details={"columns": ["d"], "rows": {"d": [0]}},
+                details={
+                    "columns": ["d"],
+                    "rows": [0],
+                    "column_indices": {"d": [0]},
+                },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [0]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0]}
+            ).to_dict()
+        ],
     }
 
 
@@ -182,9 +213,48 @@ def test_outliers_data_check_warnings_has_nan():
                 message="Column(s) '25', '55', '72' are likely to have outlier data.",
                 data_check_name=outliers_data_check_name,
                 message_code=DataCheckMessageCode.HAS_OUTLIERS,
-                details={"columns": [25, 55, 72], "rows": {25: [3], 55: [5], 72: [10]}},
+                details={
+                    "columns": [25, 55, 72],
+                    "rows": [3, 5, 10],
+                    "column_indices": {25: [3], 55: [5], 72: [10]},
+                },
             ).to_dict()
         ],
         "errors": [],
-        "actions": [{"code": "DROP_ROWS", "metadata": {"indices": [3, 5, 10]}}],
+        "actions": [
+            DataCheckAction(
+                DataCheckActionCode.DROP_ROWS, metadata={"rows": [3, 5, 10]}
+            ).to_dict()
+        ],
+    }
+
+
+@pytest.mark.parametrize("data_type", ["int", "mixed"])
+def test_boxplot_stats(data_type):
+    test = pd.Series(
+        [32, 33, 34, None, 96, 36, 37, 1.5 if data_type == "mixed" else 1, 2]
+    )
+
+    quantiles = test.quantile([0.25, 0.5, 0.75]).to_dict()
+    iqr = quantiles[0.75] - quantiles[0.25]
+    field_bounds = (quantiles[0.25] - (iqr * 1.5), quantiles[0.75] + (iqr * 1.5))
+    pct_outliers = (
+        len(test[test <= field_bounds[0]].tolist())
+        + len(test[test >= field_bounds[1]].tolist())
+    ) / test.count()
+
+    assert OutliersDataCheck.get_boxplot_data(test) == {
+        "score": OutliersDataCheck._no_outlier_prob(test.count(), pct_outliers),
+        "pct_outliers": pct_outliers,
+        "values": {
+            "q1": quantiles[0.25],
+            "median": quantiles[0.5],
+            "q3": quantiles[0.75],
+            "low_bound": field_bounds[0],
+            "high_bound": field_bounds[1],
+            "low_values": test[test < field_bounds[0]].tolist(),
+            "high_values": test[test > field_bounds[1]].tolist(),
+            "low_indices": test[test < field_bounds[0]].index.tolist(),
+            "high_indices": test[test > field_bounds[1]].index.tolist(),
+        },
     }
