@@ -1,4 +1,5 @@
 import re
+from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
@@ -162,6 +163,100 @@ def test_partial_dependence_with_non_numeric_columns(
     assert not part_dep.isnull().any(axis=None)
 
 
+@patch(
+    "evalml.pipelines.BinaryClassificationPipeline.predict_proba",
+    side_effect=lambda X: np.array([[0.2, 0.8]] * X.shape[0]),
+)
+def test_partial_dependence_with_ww_category_columns(
+    mock_predict_proba, fraud_100, logistic_regression_binary_pipeline_class
+):
+    X, y = fraud_100
+    X.ww.set_types(
+        logical_types={
+            "store_id": "PostalCode",
+            "country": "CountryCode",
+            "region": "SubRegionCode",
+        }
+    )
+
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+
+    part_dep = partial_dependence(pipeline, X, features="store_id")
+    assert list(part_dep.columns) == [
+        "feature_values",
+        "partial_dependence",
+        "class_label",
+    ]
+    assert len(part_dep["partial_dependence"]) == 11
+    assert len(part_dep["feature_values"]) == 11
+    assert not part_dep.isnull().any(axis=None)
+
+    part_dep = partial_dependence(pipeline, X, features="country")
+    assert list(part_dep.columns) == [
+        "feature_values",
+        "partial_dependence",
+        "class_label",
+    ]
+    assert len(part_dep["partial_dependence"]) == 8
+    assert len(part_dep["feature_values"]) == 8
+    assert not part_dep.isnull().any(axis=None)
+
+    part_dep = partial_dependence(pipeline, X, features="region")
+    assert list(part_dep.columns) == [
+        "feature_values",
+        "partial_dependence",
+        "class_label",
+    ]
+    assert len(part_dep["partial_dependence"]) == 11
+    assert len(part_dep["feature_values"]) == 11
+    assert not part_dep.isnull().any(axis=None)
+
+
+@patch(
+    "evalml.pipelines.BinaryClassificationPipeline.predict_proba",
+    side_effect=lambda X: np.array([[0.2, 0.8]] * X.shape[0]),
+)
+def test_two_way_partial_dependence_with_ww_category_columns(
+    mock_predict_proba, fraud_100, logistic_regression_binary_pipeline_class
+):
+    X, y = fraud_100
+    X.ww.set_types(
+        logical_types={
+            "store_id": "PostalCode",
+            "country": "CountryCode",
+            "region": "SubRegionCode",
+        }
+    )
+
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+
+    part_dep = partial_dependence(pipeline, X, features=("store_id", "country"))
+    assert "class_label" in part_dep.columns
+    assert part_dep["class_label"].nunique() == 1
+    assert len(part_dep.index) == len(set(X["store_id"]))
+    assert len(part_dep.columns) == len(set(X["country"])) + 1
+
+    grid_resolution = 5
+    part_dep = partial_dependence(
+        pipeline, X, features=("store_id", "amount"), grid_resolution=grid_resolution
+    )
+    assert "class_label" in part_dep.columns
+    assert part_dep["class_label"].nunique() == 1
+    assert len(part_dep.index) == len(set(X["store_id"]))
+    assert len(part_dep.columns) == grid_resolution + 1
+
+    grid_resolution = 5
+    part_dep = partial_dependence(
+        pipeline, X, features=("amount", "store_id"), grid_resolution=grid_resolution
+    )
+    assert "class_label" in part_dep.columns
+    assert part_dep["class_label"].nunique() == 1
+    assert len(part_dep.columns) == len(set(X["store_id"])) + 1
+    assert len(part_dep.index) == grid_resolution
+
+
 def test_partial_dependence_baseline():
     X = pd.DataFrame([[1, 0], [0, 1]])
     y = pd.Series([0, 1])
@@ -528,11 +623,8 @@ def test_two_way_partial_dependence_ice_plot(logistic_regression_binary_pipeline
         assert ind_df.shape == (3, 3)
 
 
-@pytest.mark.parametrize("use_sklearn", [True, False])
 @pytest.mark.parametrize("problem_type", [ProblemTypes.BINARY, ProblemTypes.REGRESSION])
-def test_partial_dependence_ensemble_pipeline(
-    problem_type, use_sklearn, X_y_binary, X_y_regression
-):
+def test_partial_dependence_ensemble_pipeline(problem_type, X_y_binary, X_y_regression):
     if problem_type == ProblemTypes.BINARY:
         X, y = X_y_binary
         input_pipelines = [
@@ -546,9 +638,7 @@ def test_partial_dependence_ensemble_pipeline(
             RegressionPipeline(["Elastic Net Regressor"]),
         ]
     pipeline = _make_stacked_ensemble_pipeline(
-        input_pipelines=input_pipelines,
-        problem_type=problem_type,
-        use_sklearn=use_sklearn,
+        input_pipelines=input_pipelines, problem_type=problem_type
     )
     pipeline.fit(X, y)
     part_dep = partial_dependence(pipeline, X, features=0, grid_resolution=5)
@@ -581,6 +671,46 @@ def test_graph_partial_dependence(breast_cancer_local, test_pipeline):
     )
 
 
+@patch(
+    "evalml.pipelines.BinaryClassificationPipeline.predict_proba",
+    side_effect=lambda X: np.array([[0.2, 0.8]] * X.shape[0]),
+)
+def test_graph_partial_dependence_ww_categories(
+    mock_predict_proba, fraud_100, logistic_regression_binary_pipeline_class
+):
+    go = pytest.importorskip(
+        "plotly.graph_objects",
+        reason="Skipping plotting test because plotly not installed",
+    )
+    X, y = fraud_100
+    X.ww.set_types(
+        logical_types={
+            "store_id": "PostalCode",
+            "country": "CountryCode",
+            "region": "SubRegionCode",
+        }
+    )
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+
+    for feat in ["store_id", "country", "region"]:
+        fig = graph_partial_dependence(pipeline, X, features=feat)
+        assert isinstance(fig, go.Figure)
+        fig_dict = fig.to_dict()
+
+        assert fig_dict["data"][0]["type"] == "bar"
+
+        assert fig_dict["layout"]["title"]["text"] == f"Partial Dependence of '{feat}'"
+        assert len(fig_dict["data"]) == 1
+        assert fig_dict["data"][0]["name"] == "Partial Dependence"
+
+        part_dep_data = partial_dependence(pipeline, X, features=feat)
+        assert np.array_equal(fig_dict["data"][0]["x"], part_dep_data["feature_values"])
+        assert np.array_equal(
+            fig_dict["data"][0]["y"], part_dep_data["partial_dependence"].values
+        )
+
+
 def test_graph_two_way_partial_dependence(breast_cancer_local, test_pipeline):
     X, y = breast_cancer_local
 
@@ -611,6 +741,76 @@ def test_graph_two_way_partial_dependence(breast_cancer_local, test_pipeline):
     assert np.array_equal(fig_dict["data"][0]["z"], part_dep_data.values)
 
 
+@patch(
+    "evalml.pipelines.BinaryClassificationPipeline.predict_proba",
+    side_effect=lambda X: np.array([[0.2, 0.8]] * X.shape[0]),
+)
+def test_graph_two_way_partial_dependence_ww_categories(
+    mock_predict_proba, fraud_100, logistic_regression_binary_pipeline_class
+):
+    go = pytest.importorskip(
+        "plotly.graph_objects",
+        reason="Skipping plotting test because plotly not installed",
+    )
+    X, y = fraud_100
+    X.ww.set_types(
+        logical_types={
+            "store_id": "PostalCode",
+            "country": "CountryCode",
+            "region": "SubRegionCode",
+        }
+    )
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+
+    # Two categorical columns
+    fig = graph_partial_dependence(pipeline, X, features=("country", "region"))
+    assert isinstance(fig, go.Figure)
+    fig_dict = fig.to_dict()
+    assert (
+        fig_dict["layout"]["title"]["text"]
+        == "Partial Dependence of 'country' vs. 'region'"
+    )
+    assert len(fig_dict["data"]) == 1
+    assert fig_dict["data"][0]["name"] == "Partial Dependence"
+
+    part_dep_data = partial_dependence(pipeline, X, features=("country", "region"))
+    part_dep_data.drop(columns=["class_label"], inplace=True)
+    assert np.array_equal(fig_dict["data"][0]["z"], part_dep_data.values)
+
+    # One categorical column, entered first
+    fig = graph_partial_dependence(pipeline, X, features=("country", "lat"))
+    assert isinstance(fig, go.Figure)
+    fig_dict = fig.to_dict()
+    assert (
+        fig_dict["layout"]["title"]["text"]
+        == "Partial Dependence of 'country' vs. 'lat'"
+    )
+    assert len(fig_dict["data"]) == 1
+    assert fig_dict["data"][0]["name"] == "Partial Dependence"
+
+    part_dep_data = partial_dependence(pipeline, X, features=("country", "lat"))
+    part_dep_data.drop(columns=["class_label"], inplace=True)
+    assert np.array_equal(fig_dict["data"][0]["x"], part_dep_data.columns)
+    assert np.array_equal(fig_dict["data"][0]["z"], part_dep_data.values)
+
+    # One categorical column, entered second
+    fig = graph_partial_dependence(pipeline, X, features=("lat", "country"))
+    assert isinstance(fig, go.Figure)
+    fig_dict = fig.to_dict()
+    assert (
+        fig_dict["layout"]["title"]["text"]
+        == "Partial Dependence of 'country' vs. 'lat'"
+    )
+    assert len(fig_dict["data"]) == 1
+    assert fig_dict["data"][0]["name"] == "Partial Dependence"
+
+    part_dep_data = partial_dependence(pipeline, X, features=("country", "lat"))
+    part_dep_data.drop(columns=["class_label"], inplace=True)
+    assert np.array_equal(fig_dict["data"][0]["x"], part_dep_data.columns)
+    assert np.array_equal(fig_dict["data"][0]["z"], part_dep_data.values)
+
+
 def test_graph_partial_dependence_multiclass(
     wine_local,
     logistic_regression_multiclass_pipeline_class,
@@ -1549,3 +1749,44 @@ def test_partial_dependence_categorical_nan(fraud_100):
     assert not dep2way.isna().any().any()
     # Plus 1 in the columns because there is `class_label`
     assert dep2way.shape == (GRID_RESOLUTION, X["provider"].dropna().nunique() + 1)
+
+
+@patch(
+    "evalml.pipelines.BinaryClassificationPipeline.predict_proba",
+    side_effect=lambda X: np.array([[0.2, 0.8]] * X.shape[0]),
+)
+def test_partial_dependence_preserves_woodwork_schema(mock_predict_proba, fraud_100):
+
+    X, y = fraud_100
+    X_test = X.ww.copy()
+
+    X = X.ww[["card_id", "store_id", "amount", "provider"]]
+    X.ww.set_types({"provider": "NaturalLanguage"})
+
+    pl = BinaryClassificationPipeline(
+        component_graph={
+            "Label Encoder": ["Label Encoder", "X", "y"],
+            "Text Featurization Component": [
+                "Text Featurization Component",
+                "X",
+                "Label Encoder.y",
+            ],
+            "Imputer": ["Imputer", "Text Featurization Component.x", "Label Encoder.y"],
+            "Random Forest Classifier": [
+                "Random Forest Classifier",
+                "Imputer.x",
+                "Label Encoder.y",
+            ],
+        }
+    )
+    pl.fit(X, y)
+
+    X_test = X_test.ww[["card_id", "store_id", "amount", "provider"]]
+    X_test["provider"][-1] = None
+    X_test.ww.set_types({"provider": "NaturalLanguage"})
+
+    _ = partial_dependence(pl, X_test, "card_id", grid_resolution=5)
+    assert all(
+        call_args[0][0].ww.schema == X_test.ww.schema
+        for call_args in mock_predict_proba.call_args_list
+    )
