@@ -33,13 +33,15 @@ from evalml.pipelines.components import (
 from evalml.pipelines.components.transformers.encoders.label_encoder import (
     LabelEncoder,
 )
+from evalml.pipelines.components.utils import handle_component_class
 from evalml.pipelines.utils import (
     _get_pipeline_base_class,
-    _make_component_list_from_actions,
+    _make_pipeline_from_multiple_graphs,
     generate_pipeline_code,
     get_estimators,
     is_classification,
     make_pipeline,
+    make_pipeline_from_actions,
     rows_of_interest,
 )
 from evalml.problem_types import ProblemTypes, is_regression, is_time_series
@@ -269,49 +271,79 @@ def test_make_pipeline_problem_type_mismatch():
         make_pipeline(pd.DataFrame(), pd.Series(), Transformer, ProblemTypes.MULTICLASS)
 
 
-def test_make_component_list_from_actions():
-    assert _make_component_list_from_actions([]) == []
+@pytest.mark.parametrize("problem_type", ["binary", "multiclass", "regression"])
+def test_make_pipeline_from_actions(problem_type):
+    pipeline_class = _get_pipeline_base_class(problem_type)
 
-    actions = [DataCheckAction(DataCheckActionCode.DROP_COL, {"column": "some col"})]
-    assert _make_component_list_from_actions(actions) == [
-        DropColumns(columns=["some col"])
-    ]
+    assert make_pipeline_from_actions(problem_type, []) == pipeline_class(
+        component_graph={}
+    )
+
+    actions = [DataCheckAction(DataCheckActionCode.DROP_COL, {"columns": ["some col"]})]
+    assert make_pipeline_from_actions(problem_type, actions) == pipeline_class(
+        component_graph={"Drop Columns Transformer": [DropColumns, "X", "y"]},
+        parameters={"Drop Columns Transformer": {"columns": ["some col"]}},
+        random_seed=0,
+    )
 
     actions = [
-        DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": "some col"}),
+        DataCheckAction(
+            DataCheckActionCode.DROP_COL, metadata={"columns": ["some col"]}
+        ),
         DataCheckAction(
             DataCheckActionCode.IMPUTE_COL,
             metadata={
-                "column": None,
+                "columns": None,
                 "is_target": True,
                 "impute_strategy": "most_frequent",
             },
         ),
-        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"indices": [1, 2]}),
-    ]
-    assert _make_component_list_from_actions(actions) == [
-        TargetImputer(impute_strategy="most_frequent"),
-        DropRowsTransformer(indices_to_drop=[1, 2]),
-        DropColumns(columns=["some col"]),
+        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"rows": [1, 2]}),
     ]
 
+    assert make_pipeline_from_actions(problem_type, actions) == pipeline_class(
+        component_graph={
+            "Target Imputer": [TargetImputer, "X", "y"],
+            "Drop Columns Transformer": [DropColumns, "X", "Target Imputer.y"],
+            "Drop Rows Transformer": [
+                DropRowsTransformer,
+                "Drop Columns Transformer.x",
+                "Target Imputer.y",
+            ],
+        },
+        parameters={
+            "Target Imputer": {"impute_strategy": "most_frequent", "fill_value": None},
+            "Drop Columns Transformer": {"columns": ["some col"]},
+            "Drop Rows Transformer": {"indices_to_drop": [1, 2]},
+        },
+        random_seed=0,
+    )
+
+
+@pytest.mark.parametrize("problem_type", ["binary", "multiclass", "regression"])
+def test_make_pipeline_from_actions_with_duplicate_actions(problem_type):
+    pipeline_class = _get_pipeline_base_class(problem_type)
 
-def test_make_component_list_from_actions_with_duplicate_actions():
     actions = [
-        DataCheckAction(DataCheckActionCode.DROP_COL, {"column": "some col"}),
-        DataCheckAction(DataCheckActionCode.DROP_COL, {"column": "some other col"}),
-    ]
-    assert _make_component_list_from_actions(actions) == [
-        DropColumns(columns=["some col", "some other col"])
+        DataCheckAction(DataCheckActionCode.DROP_COL, {"columns": ["some col"]}),
+        DataCheckAction(DataCheckActionCode.DROP_COL, {"columns": ["some other col"]}),
     ]
+    assert make_pipeline_from_actions(problem_type, actions) == pipeline_class(
+        component_graph={"Drop Columns Transformer": [DropColumns, "X", "y"]},
+        parameters={
+            "Drop Columns Transformer": {"columns": ["some col", "some other col"]}
+        },
+        random_seed=0,
+    )
     actions = [
-        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"indices": [0, 3]}),
-        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"indices": [1, 2]}),
-    ]
-    assert _make_component_list_from_actions(actions) == [
-        DropRowsTransformer(indices_to_drop=[0, 3]),
-        DropRowsTransformer(indices_to_drop=[1, 2]),
+        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 1, 3]}),
+        DataCheckAction(DataCheckActionCode.DROP_ROWS, metadata={"rows": [1, 2]}),
     ]
+    assert make_pipeline_from_actions(problem_type, actions) == pipeline_class(
+        component_graph={"Drop Rows Transformer": [DropRowsTransformer, "X", "y"]},
+        parameters={"Drop Rows Transformer": {"indices_to_drop": [0, 1, 2, 3]}},
+        random_seed=0,
+    )
 
 
 @pytest.mark.parametrize(
@@ -806,3 +838,38 @@ def test_rows_of_interest_empty(mock_fit, mock_pred_proba):
     mock_pred_proba.return_value = predicted_proba_values
     vals = rows_of_interest(pipeline, X, y, epsilon=0.5, types="correct")
     assert len(vals) == 0
+
+
+def test_make_pipeline_from_multiple_graphs_with_sampler(X_y_binary):
+    X, y = X_y_binary
+    estimator = handle_component_class("Random Forest Classifier")
+    pipeline_1 = make_pipeline(
+        X,
+        y,
+        estimator,
+        ProblemTypes.BINARY,
+        sampler_name="Undersampler",
+        use_estimator=False,
+    )
+    pipeline_2 = make_pipeline(
+        X,
+        y,
+        estimator,
+        ProblemTypes.BINARY,
+        sampler_name="Undersampler",
+        use_estimator=False,
+    )
+    input_pipelines = [pipeline_1, pipeline_2]
+
+    combined_pipeline = _make_pipeline_from_multiple_graphs(
+        input_pipelines=input_pipelines,
+        estimator=estimator,
+        problem_type=ProblemTypes.BINARY,
+    )
+    second_pipeline_sampler = (
+        "Pipeline w/ Label Encoder + Imputer + Undersampler Pipeline 2 - Undersampler.y"
+    )
+    assert (
+        combined_pipeline.component_graph.get_inputs("Random Forest Classifier")[2]
+        == second_pipeline_sampler
+    )
