@@ -1,4 +1,5 @@
 import os
+import pickle
 import re
 from unittest.mock import patch
 
@@ -208,6 +209,33 @@ def test_load_pickled_pipeline_with_custom_objective(
     ) == pipeline.score(X, y, [objective])
 
 
+def test_pickled_pipeline_preserves_threshold(
+    X_y_binary, tmpdir, logistic_regression_binary_pipeline_class
+):
+    X, y = X_y_binary
+    path = os.path.join(str(tmpdir), "pickled_pipe.pkl")
+    pipeline = BinaryClassificationPipeline(["Imputer", "Decision Tree Classifier"])
+    with open(path, "wb") as f:
+        pickle.dump(pipeline, f)
+
+    with open(path, "rb") as f:
+        pipe = pickle.load(f)
+    assert pipe == pipeline
+    assert pipe.threshold is None
+    assert not pipe._is_fitted
+
+    pipeline.fit(X, y)
+    preds = pipeline.predict_proba(X).iloc[:, -1]
+    pipeline.optimize_threshold(X, y, preds, Precision())
+    with open(path, "wb") as f:
+        pickle.dump(pipeline, f)
+
+    with open(path, "rb") as f:
+        pipe = pickle.load(f)
+    assert pipe == pipeline
+    assert pipe.threshold is not None
+
+
 def test_reproducibility(X_y_binary, logistic_regression_binary_pipeline_class):
     X, y = X_y_binary
     objective = FraudCost(
