@@ -1,3 +1,4 @@
+"""Bayesian Optimizer."""
 import logging
 import warnings
 
@@ -13,9 +14,26 @@ logger = logging.getLogger(__name__)
 class SKOptTuner(Tuner):
     """Bayesian Optimizer.
 
-    Arguments:
+    Args:
         pipeline_hyperparameter_ranges (dict): A set of hyperparameter ranges corresponding to a pipeline's parameters.
         random_seed (int): The seed for the random number generator. Defaults to 0.
+
+    Examples:
+        >>> tuner = SKOptTuner({'My Component': {'param a': [0.0, 10.0], 'param b': ['a', 'b', 'c']}})
+        >>> proposal = tuner.propose()
+        ...
+        >>> assert proposal.keys() == {'My Component'}
+        >>> assert proposal['My Component'] == {'param a': 5.928446182250184, 'param b': 'c'}
+        ...
+        >>> for each in range(7):
+        ...     print(tuner.propose())
+        {'My Component': {'param a': 8.57945617622757, 'param b': 'c'}}
+        {'My Component': {'param a': 6.235636967859724, 'param b': 'b'}}
+        {'My Component': {'param a': 2.9753460654447235, 'param b': 'a'}}
+        {'My Component': {'param a': 2.7265629458011325, 'param b': 'b'}}
+        {'My Component': {'param a': 8.121687287754932, 'param b': 'b'}}
+        {'My Component': {'param a': 3.927847961008298, 'param b': 'c'}}
+        {'My Component': {'param a': 3.3739616041726843, 'param b': 'b'}}
     """
 
     def __init__(self, pipeline_hyperparameter_ranges, random_seed=0):
@@ -30,12 +48,16 @@ class SKOptTuner(Tuner):
     def add(self, pipeline_parameters, score):
         """Add score to sample.
 
-        Arguments:
+        Args:
             pipeline_parameters (dict): A dict of the parameters used to evaluate a pipeline
             score (float): The score obtained by evaluating the pipeline with the provided parameters
 
         Returns:
             None
+
+        Raises:
+            Exception: If skopt tuner errors.
+            ParameterError: If skopt receives invalid parameters.
         """
         # skip adding nan scores
         if pd.isnull(score):
@@ -61,7 +83,7 @@ class SKOptTuner(Tuner):
         """Returns a suggested set of parameters to train and score a pipeline with, based off the search space dimensions and prior samples.
 
         Returns:
-            dict: Proposed pipeline parameters
+            dict: Proposed pipeline parameters.
         """
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
