@@ -2,7 +2,7 @@
 import numpy as np
 import pandas as pd
 import woodwork as ww
-from woodwork.logical_types import Datetime, Ordinal, Unknown
+from woodwork.logical_types import Unknown
 
 from evalml.utils.gen_utils import is_all_numeric
 
@@ -45,7 +45,7 @@ def _raise_value_error_if_nullable_types_detected(data):
         )
 
 
-def infer_feature_types(data, feature_types=None):
+def infer_feature_types(data, feature_types=None, ignore_nullable_types=False):
     """Create a Woodwork structure from the given list, pandas, or numpy input, with specified types for columns. If a column's type is not specified, it will be inferred by Woodwork.
 
     Args:
@@ -53,6 +53,7 @@ def infer_feature_types(data, feature_types=None):
         feature_types (string, ww.logical_type obj, dict, optional): If data is a 2D structure, feature_types must be a dictionary
             mapping column names to the type of data represented in the column. If data is a 1D structure, then feature_types must be
             a Woodwork logical type or a string representing a Woodwork logical type ("Double", "Integer", "Boolean", "Categorical", "Datetime", "NaturalLanguage")
+        ignore_nullable_types (bool): Whether to ignore raising an error upon detection of Nullable types. Defaults to False.
 
     Returns:
         A Woodwork data structure where the data type of each column was either specified or inferred.
@@ -65,7 +66,8 @@ def infer_feature_types(data, feature_types=None):
     elif isinstance(data, np.ndarray):
         data = _numpy_to_pandas(data)
 
-    _raise_value_error_if_nullable_types_detected(data)
+    if not ignore_nullable_types:
+        _raise_value_error_if_nullable_types_detected(data)
 
     def convert_all_nan_unknown_to_double(data):
         def is_column_pd_na(data, col):
@@ -113,45 +115,6 @@ def infer_feature_types(data, feature_types=None):
         return convert_all_nan_unknown_to_double(ww_data)
 
 
-def _retain_custom_types_and_initalize_woodwork(
-    old_logical_types, new_dataframe, ltypes_to_ignore=None
-):
-    """Helper method which will take an old Woodwork data structure and a new pandas data structure and return a new data structure that will try to retain as many logical types from the old data structure that exist in the new pandas data structure as possible.
-
-    Args:
-        old_logical_types (Dict): Logical types to try to retain.
-        new_dataframe (pd.DataFrame): Pandas data structure
-        ltypes_to_ignore (list): List of Woodwork logical types to ignore. Columns from the old DataFrame that have a logical type
-        specified in this list will not have their logical types carried over to the new DataFrame returned
-
-    Returns:
-        A new DataFrame where any of the columns that exist in the old input DataFrame and the new DataFrame try to retain
-        the original logical type, if possible and not specified to be ignored.
-    """
-    if isinstance(new_dataframe, pd.Series):
-        return ww.init_series(new_dataframe, old_logical_types)
-    if ltypes_to_ignore is None:
-        ltypes_to_ignore = []
-
-    new_logical_types = {}
-    for (k, v) in old_logical_types.items():
-        if isinstance(v, (Ordinal, Datetime)):
-            new_logical_types[k] = v
-        else:
-            new_logical_types[k] = type(v)
-
-    col_intersection = set(new_logical_types.keys()).intersection(
-        set(new_dataframe.columns)
-    )
-    retained_logical_types = {
-        col: ltype
-        for col, ltype in new_logical_types.items()
-        if col in col_intersection and ltype not in ltypes_to_ignore
-    }
-    new_dataframe.ww.init(logical_types=retained_logical_types)
-    return new_dataframe
-
-
 def _convert_numeric_dataset_pandas(X, y):
     """Convert numeric and non-null data to pandas datatype. Raises ValueError if there is null or non-numeric data. Used with data sampler strategies.
 
